.. beluga documentation master file, created by
   sphinx-quickstart on Tue Mar  6 23:26:39 2018.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

.. include:: ../../README.rst

Contents
========

.. toctree::
   :maxdepth: 2

   problemsetup.rst
   features.rst
   unittests.rst
   nomenclature.rst
   modules/beluga.rst
   modules/bvpsol.rst
   modules/codegen.rst
   modules/continuation.rst
   modules/ivpsol/ivpsol.rst
   modules/liepack/liepack.rst
   modules/optimlib.rst


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

License
=======

.. include:: ../../LICENSE
